#
# spec file for package python3-urllib3
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-urllib3
Version:        1.19.1
Release:        1.1
Summary:        HTTP library with thread-safe connection pooling, file post, and more
License:        MIT
Group:          Development/Languages/Python
Url:            http://urllib3.readthedocs.org/
Source:         https://files.pythonhosted.org/packages/source/u/urllib3/urllib3-%{version}.tar.gz
# PATCH-FIX-OPENSUSE speilicke@suse.com -- We need no coverage report
Patch1:         urllib3-test-no-coverage.patch
# PATCH-FEATURE-UPSTREAM -- use set_default_verify_paths() if no certificate path is supplied
# should be removed in the future, see SR#437853
Patch2:         urllib3-ssl-default-context.patch
# PATCH-FIX-OPENSUSE -- do not use unsupported SSLv3 in tests
Patch3:         urllib3-test-ssl-drop-sslv3.patch
# PATCH-FIX-OPENSUSE -- increase the timeout values in tests so it doesn't fail to build on overloaded systems
Patch4:         increase_timeout_value.patch
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
# Test requirements:
BuildRequires:  python3-mock >= 1.3.0
BuildRequires:  python3-nose >= 1.3.7
BuildRequires:  python3-nose-exclude >= 0.4.1
BuildRequires:  python3-tornado >= 4.2.1
Requires:       python3-wheel >= 0.24.0
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Highlights

- Re-use the same socket connection for multiple requests
  (HTTPConnectionPool and HTTPSConnectionPool)
  (with optional client-side certificate verification).
- File posting (encode_multipart_formdata).
- Built-in redirection and retries (optional).
- Supports gzip and deflate decoding.
- Thread-safe and sanity-safe.
- Works with AppEngine, gevent, and eventlib.
- Tested on Python 2.6+ and Python 3.3+, 100% unit test coverage.
- Small and easy to understand codebase perfect for extending and building upon.
  For a more comprehensive solution, have a look at
  Requests which is also powered by urllib3.

%prep
%setup -q -n urllib3-%{version}
%patch1 -p1
%patch2 -p1
%if 0%{?suse_version} && 0%{?suse_version} > 1310
%patch3 -p1
%endif
%patch4 -p1

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
rm -rf build
PYTHONPATH="%{buildroot}%{python_sitelib}" nosetests \
	--exclude-test=test.with_dummyserver.test_proxy_poolmanager.TestHTTPProxyManager.test_https_proxy_timeout \
	--exclude-test=test.with_dummyserver.test_proxy_poolmanager.TestHTTPProxyManager.test_https_proxy_pool_timeout \
%if 0%{?suse_version} && 0%{?suse_version} <= 1320
	--exclude-test=test.with_dummyserver.test_proxy_poolmanager.TestIPv6HTTPProxyManager.test_basic_ipv6_proxy \
%endif
	--exclude-test=test.with_dummyserver.test_proxy_poolmanager.TestHTTPProxyManager.test_headerdict \
	--exclude-test=test.with_dummyserver.test_proxy_poolmanager.TestHTTPProxyManager.test_headers \
	--exclude-test=test.with_dummyserver.test_poolmanager.TestPoolManager.test_headers \
	--exclude-test=test.with_dummyserver.test_https.TestHTTPS_IPv6Addr \
	--ignore-files=test_socks.py

%files
%defattr(-,root,root,-)
%doc CHANGES.rst CONTRIBUTORS.txt LICENSE.txt README.rst
%{python3_sitelib}/urllib3
%{python3_sitelib}/urllib3-%{version}-py%{py3_ver}.egg-info

%changelog
* Mon Feb 20 2017 alarrosa@suse.com
- Add increase_timeout_value.patch to increase the value
  of timeout values in tests so the package doesn't fail
  to build when OBS is overloaded.
* Tue Feb 14 2017 hpj@urpla.net
- Add BuildRoot to fix build on less forgiving targets
* Thu Nov 17 2016 arun@gmx.de
- specfile:
  * updated coverage patch
  * updated patch for sslv3 tests
- update to version 1.19.1:
  * Fixed AppEngine import that didn't function on Python 3.5. (Pull
    [#1025])
- changes from version 1.19:
  * urllib3 now respects Retry-After headers on 413, 429, and 503
    responses when using the default retry logic. (Pull #955)
  * Remove markers from setup.py to assist ancient setuptools
    versions. (Issue #986)
  * Disallow superscripts and other integerish things in URL
    ports. (Issue #989)
  * Allow urllib3's HTTPResponse.stream() method to continue to work
    with non-httplib underlying FPs. (Pull #990)
  * Empty filenames in multipart headers are now emitted as such,
    rather than being supressed. (Issue #1015)
  * Prefer user-supplied Host headers on chunked uploads. (Issue
    [#1009])
* Thu Oct 27 2016 arun@gmx.de
- update urllib3-ssl-default-context.patch
- update to version 1.18.1:
  * CVE-2016-9015. Users who are using urllib3 version 1.17 or 1.18 along with
    PyOpenSSL injection and OpenSSL 1.1.0 *must* upgrade to this version. This
    release fixes a vulnerability whereby urllib3 in the above configuration
    would silently fail to validate TLS certificates due to erroneously setting
    invalid flags in OpenSSL's ``SSL_CTX_set_verify`` function. These erroneous
    flags do not cause a problem in OpenSSL versions before 1.1.0, which
    interprets the presence of any flag as requesting certificate validation.
    There is no PR for this patch, as it was prepared for simultaneous disclosure
    and release. There will be a PR for the equivalent fix in the master branch.
* Mon Sep 26 2016 arun@gmx.de
- update to version 1.18:
  * Fixed incorrect message for IncompleteRead exception. (PR #973)
  * Accept "iPAddress" subject alternative name fields in TLS
    certificates.  (Issue #258)
  * Fixed consistency of "HTTPResponse.closed" between Python 2 and 3.
    (Issue #977)
  * Fixed handling of wildcard certificates when using
    PyOpenSSL. (Issue #979)
* Sat Sep 10 2016 arun@gmx.de
- specfile:
  * update line numbers in urllib3-test-ssl-drop-sslv3.patch
- update to version 1.17:
  * Accept "SSLContext" objects for use in SSL/TLS negotiation. (Issue
    [#835])
  * ConnectionPool debug log now includes scheme, host, and
    port. (Issue #897)
  * Substantially refactored documentation. (Issue #887)
  * Used URLFetch default timeout on AppEngine, rather than hardcoding
    our own.  (Issue #858)
  * Normalize the scheme and host in the URL parser (Issue #833)
  * "HTTPResponse" contains the last "Retry" object, which now also
    contains retries history. (Issue #848)
  * Timeout can no longer be set as boolean, and must be greater than
    zero.  (PR #924)
  * Removed pyasn1 and ndg-httpsclient from dependencies used for
    PyOpenSSL. We now use cryptography and idna, both of which are
    already dependencies of PyOpenSSL. (PR #930)
  * Fixed infinite loop in "stream" when amt=None. (Issue #928)
  * Try to use the operating system's certificates when we are using
    an "SSLContext". (PR #941)
  * Updated cipher suite list to allow ChaCha20+Poly1305. AES-GCM is
    preferred to ChaCha20, but ChaCha20 is then preferred to
    everything else. (PR #947)
  * Updated cipher suite list to remove 3DES-based cipher suites. (PR
    [#958])
  * Removed the cipher suite fallback to allow HIGH ciphers. (PR #958)
  * Implemented "length_remaining" to determine remaining content to
    be read. (PR #949)
  * Implemented "enforce_content_length" to enable exceptions when
    incomplete data chunks are received. (PR #949)
  * Dropped connection start, dropped connection reset, redirect,
    forced retry, and new HTTPS connection log levels to DEBUG, from
    INFO. (PR #967)
* Sun Jun 19 2016 arun@gmx.de
- update to version 1.16:
  * Disable IPv6 DNS when IPv6 connections are not possible. (Issue
    [#840])
  * Provide "key_fn_by_scheme" pool keying mechanism that can be
    overridden. (Issue #830)
  * Normalize scheme and host to lowercase for pool keys, and include
    "source_address". (Issue #830)
  * Cleaner exception chain in Python 3 for "_make_request".  (Issue
    [#861])
  * Fixed installing "urllib3[socks]" extra. (Issue #864)
  * Fixed signature of "ConnectionPool.close" so it can actually
    safely be called by subclasses. (Issue #873)
  * Retain "release_conn" state across retries. (Issues #651, #866)
  * Add customizable "HTTPConnectionPool.ResponseCls", which defaults
    to "HTTPResponse" but can be replaced with a subclass. (Issue
    [#879])
* Mon Jun 13 2016 toddrme2178@gmail.com
- Remove unneeded test dependencies.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Tue Apr 12 2016 arun@gmx.de
- update to version 1.15.1:
  * Fix packaging to include backports module. (Issue #841)
* Sat Apr  9 2016 arun@gmx.de
- specfile:
  * add setuptools
- update to version 1.15:
  * Added Retry(raise_on_status=False). (Issue #720)
  * Always use setuptools, no more distutils fallback. (Issue #785)
  * Dropped support for Python 3.2. (Issue #786)
  * Chunked transfer encoding when requesting with "chunked=True".
    (Issue #790)
  * Fixed regression with IPv6 port parsing. (Issue #801)
  * Append SNIMissingWarning messages to allow users to specify it in
    the PYTHONWARNINGS environment variable. (Issue #816)
  * Handle unicode headers in Py2. (Issue #818)
  * Log certificate when there is a hostname mismatch. (Issue #820)
  * Preserve order of request/response headers. (Issue #821)
* Tue Apr  5 2016 hpj@urpla.net
- don't apply urllib3-test-ssl-drop-sslv3.patch for openSUSE 13.1
  and below: PROTOCOL_TLSv1_2 is not available there
* Wed Mar  2 2016 jmatejek@suse.com
- synchronize spec file and patches with python2 version:
  * enable most tests
  * urllib3-ssl-default-context.patch: use ssl's default context
    for native ssl the same way it is used for pyopenssl
  * urllib3-test-ssl-drop-sslv3.patch: do not use SSLv3 protocol
  * drop unneeded 0001-Don-t-pin-dependency-to-exact-version.patch
- not adding optional dependencies of the pyopenssl module, because
  ndg-httpsclient doesn't exist yet, so the pyopenssl module is unusable
* Thu Dec 31 2015 arun@gmx.de
- update to version 1.14:
  * contrib: SOCKS proxy support! (Issue #762)
  * Fixed AppEngine handling of transfer-encoding header and bug
    in Timeout defaults checking. (Issue #763)
* Sun Dec 20 2015 arun@gmx.de
- update to version 1.13.1:
  * Fixed regression in IPv6 + SSL for match_hostname. (Issue #761)
* Tue Dec 15 2015 arun@gmx.de
- specfile:
  * updated no-coverage patch
- update to version 1.13:
  * Fixed "pip install urllib3[secure]" on modern pip. (Issue #706)
  * pyopenssl: Fixed SSL3_WRITE_PENDING error. (Issue #717)
  * pyopenssl: Support for TLSv1.1 and TLSv1.2. (Issue #696)
  * Close connections more defensively on exception. (Issue #734)
  * Adjusted "read_chunked" to handle gzipped, chunk-encoded bodies without
    repeatedly flushing the decoder, to function better on Jython. (Issue #743)
  * Accept "ca_cert_dir" for SSL-related PoolManager configuration. (Issue #758)
* Fri Sep 25 2015 p.drouand@gmail.com
- Initial release (version 1.12)
- Add patches
  * 0001-Don-t-pin-dependency-to-exact-version.patch
  * urllib3-test-no-coverage.patch
